/**
 * @overview WMF Package
 * @author Jan "Waffle" Christophersen
 * @copyright (c) Jan "Waffle" Christophersen
 */

'use strict';

Object.defineProperty(exports, '__esModule', {
  value: true
});

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _libWmf = require('./lib/wmf');

var _libWmf2 = _interopRequireDefault(_libWmf);

/**
 * Parses the GTA:MP config and removes all non-wmf-related props.
 *
 * @returns {Object}
 */
function parseConfig() {
  var config = JSON.parse(gtamp.server.config);
  var finalConfig = {};

  var props = Object.getOwnPropertyNames(config);
  for (var idx = 0; idx < props.length; idx++) {
    if (props[idx].startsWith('wmf')) {
      finalConfig[props[idx].charAt(3).toLowerCase() + props[idx].substr(4)] = config[props[idx]];
    }
  }
  return finalConfig;
}

/**
 * Initializes WMF.
 *
 * @see {WMF#constructor}
 * @returns {WMF}
 */

exports['default'] = (function () {
  if (typeof gtamp === 'undefined' || typeof events === 'undefined') {
    throw new Error('GTA:MP interface is missing');
  }

  // Check for existing wmf instance, return it if it exists. otherwise create a new one.
  var instance = events.Call('__wmfInstance');

  if (instance.length === 0) {
    var _ret = (function () {
      // parse the GTAMP config
      var wmf = new _libWmf2['default'](parseConfig());
      events.Add('__wmfInstance', function () {
        return wmf;
      });
      return {
        v: wmf
      };
    })();

    if (typeof _ret === 'object') return _ret.v;
  } else if (instance.length > 1) {
    throw new Error('multiple wmf instances?');
  }

  return instance[0];
})();

module.exports = exports['default'];
//# sourceMappingURL=index.js.map